From: Andreas Joseph Krogh <andreas@visena.com>
To: Jonathan S. Katz <jkatz@postgresql.org>
Cc: Andres Freund <andres@anarazel.de>
Cc: Robert Haas <robertmhaas@gmail.com>
Cc: Alvaro Herrera <alvherre@2ndquadrant.com>
Cc: PostgreSQL Hackers <pgsql-hackers@lists.postgresql.org>
Subject: Re: Query is over 2x slower with jit=on
Date: Thu, 23 Aug 2018 09:14:56 +0200 (CEST)
Message-ID: <VisenaEmail.2.c105fe39c156917b.165659f1429@tc7-visena> (raw)
In-Reply-To: <7884E7AD-2C41-496E-9829-66B79385DFC7@postgresql.org>
På torsdag 23. august 2018 kl. 03:00:42, skrev Jonathan S. Katz <
jkatz@postgresql.org <mailto:jkatz@postgresql.org>>:
> On Aug 22, 2018, at 7:13 PM, Andres Freund <andres@anarazel.de> wrote:
[snip]
> For the archives sake: This likely largely is the consequence of
> building with LLVM's expensive assertions enabled, as confirmed by
> Jonathan over IM.
I recompiled with the release version of LLVM. jit=on was still slower,
but the discrepancy was not as bad as the previously reported result:
jit = off
Planning Time: 0.938 ms
Execution Time: 935.599 ms
jit = on
Planning Time: 0.951 ms
JIT:
Functions: 184
Generation Time: 17.605 ms
Inlining: true
Inlining Time: 20.522 ms
Optimization: true
Optimization Time: 1001.034 ms
Emission Time: 665.319 ms
Execution Time: 2491.560 ms
However, it was still 2x+ slower, so still +1ing for open items.
I compiled with whatever switches LLVM that comes with Ubuntu 18.04 is built
with, and without debugging or assertions.
--
Andreas Joseph Krogh
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Reply to all the recipients using the --to and --cc options:
reply via email
To: pgsql-hackers@postgresql.org
Cc: andreas@visena.com, jkatz@postgresql.org, andres@anarazel.de, robertmhaas@gmail.com, alvherre@2ndquadrant.com, pgsql-hackers@lists.postgresql.org
Subject: Re: Query is over 2x slower with jit=on
In-Reply-To: <VisenaEmail.2.c105fe39c156917b.165659f1429@tc7-visena>
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox